package com.zy.omp.controller.wx;

import com.zy.omp.common.ServerResponse;
import com.zy.omp.common.controller.BaseController;
import com.zy.omp.pojo.io.CallRecordsIO;
import com.zy.omp.pojo.io.NewsIO;
import com.zy.omp.service.CallRecordsService;
import com.zy.omp.service.SetBaseService;
import com.zy.omp.service.NewsService;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import javax.annotation.Resource;

/**
 * 获取设备设置相关接口
 *
 * @author yang xiao kun
 * create on 2021/1/21
 */
@RestController
@RequestMapping("omp/api/wx/setInfo")
public class SetInfoController extends BaseController {

    @Resource
    private SetBaseService setBaseService;
    @Resource
    private CallRecordsService callRecordsService;
    @Resource
    private NewsService setNewsService;

    /**
     * 查询设备的音量设置
     * 系统音量,通话音量,铃声音量
     *
     * @param deviceId 设备ID
     */
    @GetMapping("volume.do")
    public ServerResponse volume(String deviceId) {
        return ServerResponse.createBySuccess(setBaseService.getVolumeSet(deviceId));
    }

    /**
     * 查询设备的其他设置
     * 自动接听,定位频率,连续定位设置
     *
     * @param deviceId 设备ID
     */
    @GetMapping("other.do")
    public ServerResponse other(String deviceId) {
        return ServerResponse.createBySuccess(setBaseService.getOtherSet(deviceId));
    }

    /**
     * 获取SOS按键设置
     *
     * @param deviceId 设备ID
     */
    @GetMapping("sos.do")
    public ServerResponse sos(String deviceId) {
        return ServerResponse.createBySuccess(setBaseService.getSosSet(deviceId));
    }

    /**
     * 获取通话记录
     */
    @GetMapping("callRecords.do")
    public ServerResponse callRecords(CallRecordsIO io) {
        return ServerResponse.createBySuccess(callRecordsService.getListPage(io));
    }

    /**
     * 获取播报记录
     */
    @GetMapping("news.do")
    public ServerResponse news(NewsIO io) {
        return ServerResponse.createBySuccess(setNewsService.getListPage(io));
    }
}
