package com.zy.omp.pojo.dto;

import com.alibaba.fastjson.JSON;
import com.zy.omp.common.Constant;
import com.zy.omp.utils.DateTimeUtil;
import lombok.Data;
import lombok.NoArgsConstructor;

import java.time.LocalDateTime;
import java.util.HashMap;
import java.util.Map;

/**
 * MQTT 消息模板类
 *
 * @author yang xiao kun
 * create on 2021/1/21
 */
@Data
@NoArgsConstructor
public class MqttMsgDto {
    private String m;
    private String t;
    private String r;
    /**
     * 数据项
     */
    private Map<String, Object> data;

    /**
     * 通用构造器
     *
     * @param m        MQTT协议设置代码
     * @param deviceId 设备ID
     */
    public MqttMsgDto(String m, String deviceId) {
        this.m = m;
        this.t = Constant.TOPIC_DEVICE_CLIENT + deviceId;
        this.r = Constant.TOPIC_DEVICE_SERVER + deviceId;
        this.data = new HashMap<>();
    }

    /**
     * 由 JSON 字符串 转 MqttMsgDto 对象
     */
    public static MqttMsgDto parse(String jsonStr) {
        return JSON.parseObject(jsonStr, MqttMsgDto.class);
    }

    /**
     * 往data中添加数据 支持链式
     *
     * @param key   键
     * @param value 值
     */
    public MqttMsgDto set(String key, Object value) {
        data.put(key, value);
        return this;
    }

    /**
     * 获取json 对象
     */
    public String toJson() {
        return JSON.toJSONString(this);
    }

    /**
     * 获取 Object 数据
     */
    public Object getObject(String key) {
        return data.get(key);
    }

    /**
     * 获取String 数据
     */
    public String getString(String key) {
        return data.containsKey(key) ? data.get(key).toString() : null;
    }

    /**
     * 获取 Integer 数据
     */
    public Integer getInt(String key) {
        if (!data.containsKey(key) || data.get(key).toString().equals("")) {
            return null;
        }
        return Integer.parseInt(data.get(key).toString());
    }

    /**
     * 获取 Double 数据
     */
    public Double getDouble(String key) {
        if (!data.containsKey(key) || data.get(key).toString().equals("")) {
            return null;
        }
        return Double.parseDouble(data.get(key).toString());
    }

    /**
     * 获取 日期数据 数据
     */
    public LocalDateTime getDate(String key) {
        if (!data.containsKey(key) || data.get(key).toString().equals("")) {
            return null;
        }
        return DateTimeUtil.strToTime(data.get(key).toString());
    }

    /**
     * 获取设备ID
     */
    public String getDeviceId() {
        if (r == null) return null;
        String[] res = r.split("/");
        return res.length > 1 ? res[1] : null;
    }
}
