package com.zy.omp.schedule;

import com.zy.omp.model.Device;
import com.zy.omp.service.DeviceService;
import com.zy.omp.service.RabbitMQApi;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.context.annotation.Configuration;
import org.springframework.scheduling.annotation.Async;
import org.springframework.scheduling.annotation.EnableAsync;
import org.springframework.scheduling.annotation.EnableScheduling;
import org.springframework.scheduling.annotation.Scheduled;

import java.time.LocalDateTime;
import java.util.List;
import java.util.Set;

/**
 * 定时更新设备在线状态
 *
 * @author yang xiao kun
 * create on 2021/5/14
 */
@EnableAsync
@Configuration
@EnableScheduling
public class DeviceStatusSchedule {

    @Autowired
    private RabbitMQApi rabbitMQApi;
    @Autowired
    private DeviceService deviceService;

    /**
     * 更新频率 5分钟
     * 定时更新设备在线状态
     */
    @Async
    @Scheduled(cron = "0 0/5 * * * ?")
    public void updateDeviceStatus() {
        //全部的设备
        List<Device> devices = deviceService.list();
        Set<String> online = rabbitMQApi.getOnlineDevice();
        for (Device item : devices) {
            int status = online.contains(item.getClientId()) ? 1 : 0;
            item.setStatus(status);
            if (status == 1) {
                item.setLastOnlineTime(LocalDateTime.now());
            }
        }
        deviceService.updateDeviceStatus(devices);
    }
}
