package com.zy.omp.service;

import com.alibaba.fastjson.JSON;
import com.alibaba.fastjson.JSONArray;
import com.alibaba.fastjson.JSONObject;
import com.zy.omp.utils.HttpUtil;
import org.springframework.http.HttpHeaders;
import org.springframework.stereotype.Component;

import java.util.HashMap;
import java.util.HashSet;
import java.util.Map;
import java.util.Set;

/**
 * RabbitMQ HTTP API接口请求
 *
 * @author yang xiao kun
 * create on 2021/5/14
 */
@Component
public class RabbitMQApi {

    /**
     * 获取在线的设备
     */
    public Set<String> getOnlineDevice() {
        String url = "http://view.ailishi.org:15672/api/connections?page=1&page_size=500";
        //请求头
        HttpHeaders headers = new HttpHeaders();
        headers.add("authorization", "Basic bHEyMDE5OkxpUXVhblJhYmJpdA==");
        String httpRes = HttpUtil.getForEntity(url, headers);
        Set<String> result = new HashSet<>();
        if (httpRes != null) {
            JSONObject jsonObject = JSON.parseObject(httpRes);
            JSONArray jsonArray = jsonObject.getJSONArray("items");
            for (int i = 0; i < jsonArray.size(); i++) {
                result.add(jsonArray.getJSONObject(i).getString("user"));
            }
        }
        return result;
    }

    /**
     * 向 MQTT 服务器申请用户,供设备进行登录
     * <p>
     * 因为存在先后问题,需要先注册用户,在开通虚拟机权限,
     * 所以逻辑为
     * 发送注册用户请求
     * 尝试申请权限
     * 如果失败,则间隔一秒再次请求
     * 如果申请次数超过3次,则尝试重新注册
     * 重新注册后再次尝试申请
     * 如果申请五次都失败,则结束方法,记录日志
     *
     * @param clientId 设备登录ID
     * @param password 设备登录密码
     */
    public void registerMqtt(String clientId, String password) {
        addRabbitMqUser(clientId, password);
        int count = 0;
        while (!setPermission(clientId)) {
            try {
                Thread.sleep(1000);
                if (count == 2) {
                    addRabbitMqUser(clientId, password);
                }
                if (count > 4) {
                    break;
                }
                count++;
            } catch (InterruptedException e) {
                e.printStackTrace();
                break;
            }
        }
    }

    /**
     * 注册 RabbitMQ 用户
     *
     * @param clientId 用户名
     * @param password 用户密码
     */
    private void addRabbitMqUser(String clientId, String password) {
        String url = "http://view.ailishi.org:15672/api/users/" + clientId;
        //请求头
        HttpHeaders headers = new HttpHeaders();
        headers.add("authorization", "Basic bHEyMDE5OkxpUXVhblJhYmJpdA==");
        //请求参数
        Map<String, String> params = new HashMap<>();
        params.put("username", clientId);
        params.put("password", password);
        params.put("tags", "");
        HttpUtil.putForJSONEntity(url, headers, JSON.toJSONString(params));
    }

    /**
     * 申请虚拟机权限
     *
     * @param clientId 用户ID
     */
    private boolean setPermission(String clientId) {
        String url = "http://view.ailishi.org:15672/api/permissions/%2F/" + clientId;
        //请求头
        HttpHeaders headers = new HttpHeaders();
        headers.add("authorization", "Basic bHEyMDE5OkxpUXVhblJhYmJpdA==");
        //请求参数
        Map<String, String> params = new HashMap<>();
        params.put("username", clientId);
        params.put("vhost", "/");
        params.put("configure", ".*");
        params.put("write", ".*");
        params.put("read", ".*");
        try {
            HttpUtil.putForJSONEntity(url, headers, JSON.toJSONString(params));
        } catch (Exception e) {
            return false;
        }
        return true;
    }
}
